.. lang:: fr

Archives
%%%%%%%%

Ceci est un exemple de page d'archives.

Vous pouvez créer ce type de page en incluant le fichier "ec_post_list.inc",
qui est créé automatiquement par éClaircie pour chaque catégorie.

.. lang:: en

Archives
%%%%%%%%

This is an example of archive page.

You can create archive by including the "ec_post_list.inc" file,
which is automatically created by éClaircie for each category.

.. lang:: all

.. code-block:: rest

   .. include:: ec_post_list.inc

.. include:: ec_post_list.inc

